#
# Programa demo SQL con FireBird
# Utilizando FireBird / InterBase desde Perl
# Una simple consulta sobre una View
# 
# Programacion Aplicada
# Universidad Nacional de Lujan
# 
# Lic. Guillermo Cherencio
#
# Se recomienda la lectura del articulo DemoDBI.doc y el seguimiento
# del programa adjunto a dicho documento PruDBI2.pl para entender el
# funcionamiento general de la interfaz DBI y como interactuar con las
# distintas bases de datos del mercado.
#
#
# Modo de ejecucion de este programa:
#
#    perl -w Ferreteria.pl
#
# Atencion!: 
# 1) Verificar que el archivo c:\windows\services
#    tenga una entrada del tipo:
#           gds_db 3050/tcp # InterBase Server
#    caso contrario, jamas se conectara a FireBird !
# 2) Por supuesto, debe tener el servidor de FireBird corriendo
# 3) Tiene que tener instalado el packet driver para FireBird
#    puede verificar los paquetes instalados utilizando PPM, 
#    desde el prompt DOS tipee:
#        PPM
#    una vez dentro de PPM ejecute el comando:
#        query DBD-InterBase
#    si PPM responde algo similar a esto:
#        DBD-InterBase [0.40] DBD::InterBase is a DBI driver for InterBase, written
#                    using InterBase C API.
#    significa que esta instalado.  Si Ud. quiere saber todos los paquetes
#    que tiene instalado su Perl, tipee solo el comando query
#    Si quiere saber todos los comandos disponibles en PPM tipee help
# 4) Para instalar el package DBD-InterBase-040 haga lo siguiente:
#    Cree una carpeta o directorio temporal cualquiera, supongamos C:\cualquiera
#    En C:\cualquiera copie DBD-InterBase-0.40.zip y luego descomprimalo
#    Dentro de C:\cualquiera, desde el prompt de DOS, tipee:
#        ppm install DBD-InterBase.ppd
# 5) Por supuesto, tiene que tener instalada la interfaz DBI, recuerde que la 
#    conexion a una b.d. desde perl es a traves de esta interfaz, de la siguiente
#    manera:
#
# Usuario <---> Programa Perl <---> Interfaz DBI <---> Packet Driver <---> S.G.B.D.
#
#    en nuestro caso:
#
# Usuario <---> Programa Perl <---> DBI <---> DBD-InterBase-040 <---> Servidor FireBird
#
#    en el cd-rom de la materia, podra encontar en \Software\Windows\perl
#    un perl previamente instalado, el cual ya tiene instalada la interfaz DBI
#    Si no tuvo acceso a esta version, teniendo una conexion abierta a internet,
#    pruebe el siguiente comando desde el prompt DOS:
#
#       ppm install DBI
#
# Para obtener mayor informacion sobre cualquier tema, desde el prompt DOS, tipee:
#
#    perldoc <topico>
#
# Por ejemplo para obtener mayor informacion sobre este packet driver, tipear:
#
#    perldoc DBD::Interbase
#
#
#

#Indico que voy a usar la interfaz DBI
use DBI;
#
# Parametros de conexion con Interbase
#

# Nombre del servidor (no poner su direccion ip)
# consejo: antes de establecer este nombre, desde el prompt DOS, tipee:
#    ping <nombre del servidor>
# si obtiene un mensaje de Reply from ...
# tiene una remota posibilidad de que pueda conectarse
my $servidor = 'localhost'; 

# Ubicacion de la base de datos dentro del servidor FireBird / Interbase
my $base =  'c:/internet/firebird/bin/ferreteria.gdb';

# Usuario a utilizar para esta conexion
my $usuario = 'sysdba';

# Password del usuario a utilizar en esta conexion 
my $password = 'masterkey';

# Flag para el manejo de errores
my $sqlerror = 0;

# Variables adicionales para volcar los datos provenientes de FireBird / Interbase
my $campo = '', @res = ();

#
# Me conecto a Interbase, base de datos ferreteria, usuario sysdba, password masterkey
#
my $dbh = DBI->connect("dbi:InterBase:database=$base;host=$servidor;ib_dialect=3",
                       "$usuario",
                       "$password",
                       { PrintError => 0 }) or $sqlerror = 1;

if ( not $sqlerror ) { #se conecto

   $sth = $dbh->prepare("SELECT * FROM vfactura") or $sqlerror = 1;

   if ( not $sqlerror ) { #se preparo el sql

      $sth->execute or $sqlerror = 1;

      if ( not $sqlerror ) { #se ejecuto el sql

         print "Recupero las Filas de vfactura:\n";

         while (@res = $sth->fetchrow_array()) { #se recuperan filas

            #muestro cada campo de cada fila
            foreach $campo ( @res ) { print "$campo\t"; }
            print "\n"; 

         }
         $sth->finish();  #libero los recursos

      } else {
         print "Error en execute:\n$DBI::errstr\n";      
      }
   } else {
      print "Error en prepare:\n$DBI::errstr\n";
   }
   $dbh->disconnect();  #me desconecto

} else {
   print "Error en conexion:\n$DBI::errstr\n";
}
exit;

